@@ -7,9 +7,9 @@
 
 #include "basictheme_p.h"
 
-#include <QGuiApplication>
-
 #include "styleselector_p.h"
+#include <QFile>
+#include <QGuiApplication>
 
 #include "loggingcategory.h"
 
@@ -134,7 +134,11 @@ BasicThemeDefinition &BasicThemeInstance::themeDefinition(QQmlEngine *engine)
     }
 
     auto componentUrl = StyleSelector::componentUrl(QStringLiteral("Theme.qml"));
-    QFile themeFile{componentUrl.toLocalFile()};
+    QString path{componentUrl.toLocalFile()};
+    if (path.isEmpty() && componentUrl.scheme() == QLatin1String("qrc")) {
+        path = QLatin1Char(':') + componentUrl.path();
+    }
+    QFile themeFile{path};
     if (themeFile.open(QIODevice::ReadOnly)) {
         auto data = themeFile.readAll();
 
@@ -159,16 +163,16 @@ BasicThemeDefinition &BasicThemeInstance::themeDefinition(QQmlEngine *engine)
             }
 
             qCWarning(KirigamiLog) << "Invalid Theme file, using default Basic theme.";
-            m_themeDefinition.reset(new BasicThemeDefinition);
+            m_themeDefinition = std::make_unique<BasicThemeDefinition>();
         } else if (qobject_cast<BasicThemeDefinition *>(result)) {
             m_themeDefinition.reset(qobject_cast<BasicThemeDefinition *>(result));
         } else {
             qCWarning(KirigamiLog) << "Warning: Theme implementations should use Kirigami.BasicThemeDefinition for its root item";
-            m_themeDefinition.reset(new CompatibilityThemeDefinition(result));
+            m_themeDefinition = std::make_unique<CompatibilityThemeDefinition>(result);
         }
     } else {
         qCDebug(KirigamiLog) << "No Theme file found, using default Basic theme";
-        m_themeDefinition.reset(new BasicThemeDefinition);
+        m_themeDefinition = std::make_unique<BasicThemeDefinition>();
     }
 
     connect(m_themeDefinition.get(), &BasicThemeDefinition::changed, this, &BasicThemeInstance::onDefinitionChanged);
@@ -178,7 +182,7 @@ BasicThemeDefinition &BasicThemeInstance::themeDefinition(QQmlEngine *engine)
 
 void BasicThemeInstance::onDefinitionChanged()
 {
-    for (auto watcher : qAsConst(watchers)) {
+    for (auto watcher : std::as_const(watchers)) {
         watcher->sync();
     }
 }
